@@ -2,6 +2,7 @@
 from __future__ import unicode_literals
 
 import sys
+import re
 from operator import itemgetter
 from itertools import groupby
 
@@ -15,6 +16,7 @@ from nameparser.config import DEFAULT_ENCODING
 
 ENCODING = 'utf-8'
 
+
 def group_contiguous_integers(data):
     """
     return list of tuples containing first and last index
@@ -27,6 +29,7 @@ def group_contiguous_integers(data):
             ranges.append((group[0], group[-1]))
     return ranges
 
+
 class HumanName(object):
     """
     Parse a person's name into individual components.
@@ -51,6 +54,8 @@ class HumanName(object):
         `per-instance config <customize.html>`_.
     :param str encoding: string representing the encoding of your input
     :param str string_format: python string formatting
+    :param str initials_format: python initials string formatting
+    :param str initials_delimter: string delimiter for initials
     """
 
     C = CONSTANTS
@@ -67,18 +72,20 @@ class HumanName(object):
     """
 
     _count = 0
-    _members = ['title','first','middle','last','suffix','nickname']
+    _members = ['title', 'first', 'middle', 'last', 'suffix', 'nickname']
     unparsable = True
     _full_name = ''
 
     def __init__(self, full_name="", constants=CONSTANTS, encoding=DEFAULT_ENCODING,
-                string_format=None):
+                 string_format=None, initials_format=None, initials_delimiter=None):
         self.C = constants
         if type(self.C) is not type(CONSTANTS):
             self.C = Constants()
 
         self.encoding = encoding
         self.string_format = string_format or self.C.string_format
+        self.initials_format = initials_format or self.C.initials_format
+        self.initials_delimiter = initials_delimiter or self.C.initials_delimiter
         # full_name setter triggers the parse
         self.full_name = full_name
 
@@ -130,7 +137,7 @@ class HumanName(object):
             # string_format = "{title} {first} {middle} {last} {suffix} ({nickname})"
             _s = self.string_format.format(**self.as_dict())
             # remove trailing punctuation from missing nicknames
-            _s = _s.replace(str(self.C.empty_attribute_default),'').replace(" ()","").replace(" ''","").replace(' ""',"")
+            _s = _s.replace(str(self.C.empty_attribute_default), '').replace(" ()", "").replace(" ''", "").replace(' ""', "")
             return self.collapse_whitespace(_s).strip(', ')
         return " ".join(self)
 
@@ -141,7 +148,7 @@ class HumanName(object):
 
     def __repr__(self):
         if self.unparsable:
-            _string = "<%(class)s : [ Unparsable ] >" % {'class': self.__class__.__name__,}
+            _string = "<%(class)s : [ Unparsable ] >" % {'class': self.__class__.__name__, }
         else:
             _string = "<%(class)s : [\n\ttitle: '%(title)s' \n\tfirst: '%(first)s' \n\tmiddle: '%(middle)s' \n\tlast: '%(last)s' \n\tsuffix: '%(suffix)s'\n\tnickname: '%(nickname)s'\n]>" % {
                 'class': self.__class__.__name__,
@@ -182,6 +189,73 @@ class HumanName(object):
                     d[m] = val
         return d
 
+    def __process_initial__(self, name_part, firstname=False):
+        """
+            Name parts may include prefixes or conjuctions. This function filters these from the name unless it is
+            a first name, since first names cannot be conjunctions or prefixes.
+        """
+        parts = name_part.split(" ")
+        initials = []
+        if len(parts) and isinstance(parts, list):
+            for part in parts:
+                if not (self.is_prefix(part) or self.is_conjunction(part)) or firstname == True:
+                    initials.append(part[0])
+        if len(initials) > 0:
+            return " ".join(initials)
+        else:
+            return self.C.empty_attribute_default
+
+    def initials_list(self):
+        """
+            Returns the initials as a list
+
+            .. doctest::
+
+                >>> name = HumanName("Sir Bob Andrew Dole")
+                >>> name.initials_list()
+                ["B", "A", "D"]
+                >>> name = HumanName("J. Doe")
+                >>> name.initials_list()
+                ["J", "D"]
+        """
+        first_initials_list = [self.__process_initial__(name, True) for name in self.first_list if name]
+        middle_initials_list = [self.__process_initial__(name) for name in self.middle_list if name]
+        last_initials_list = [self.__process_initial__(name) for name in self.last_list if name]
+        return first_initials_list + middle_initials_list + last_initials_list
+
+    def initials(self):
+        """
+            Return period-delimited initials of the first, middle and optionally last name.
+
+            :param bool include_last_name: Include the last name as part of the initials
+            :rtype: str
+
+            .. doctest::
+
+                >>> name = HumanName("Sir Bob Andrew Dole")
+                >>> name.initials()
+                "B. A. D."
+                >>> name = HumanName("Sir Bob Andrew Dole", initials_format="{first} {middle}")
+                >>> name.initials()
+                "B. A."
+        """
+
+        first_initials_list = [self.__process_initial__(name, True) for name in self.first_list if name]
+        middle_initials_list = [self.__process_initial__(name) for name in self.middle_list if name]
+        last_initials_list = [self.__process_initial__(name) for name in self.last_list if name]
+
+        initials_dict = {
+            "first":  (self.initials_delimiter + " ").join(first_initials_list) + self.initials_delimiter
+            if len(first_initials_list) else self.C.empty_attribute_default,
+            "middle": (self.initials_delimiter + " ").join(middle_initials_list) + self.initials_delimiter
+            if len(middle_initials_list) else self.C.empty_attribute_default,
+            "last": (self.initials_delimiter + " ").join(last_initials_list) + self.initials_delimiter
+            if len(last_initials_list) else self.C.empty_attribute_default
+        }
+
+        _s = self.initials_format.format(**initials_dict)
+        return self.collapse_whitespace(_s)
+
     @property
     def has_own_config(self):
         """
@@ -190,7 +264,7 @@ class HumanName(object):
         """
         return self.C is not CONSTANTS
 
-    ### attributes
+    # attributes
 
     @property
     def title(self):
@@ -259,7 +333,7 @@ class HumanName(object):
         """
         return " ".join(self.surnames_list) or self.C.empty_attribute_default
 
-    ### setter methods
+    # setter methods
 
     def _set_list(self, attr, value):
         if isinstance(value, list):
@@ -270,8 +344,8 @@ class HumanName(object):
             val = []
         else:
             raise TypeError(
-                    "Can only assign strings, lists or None to name attributes."
-                    " Got {0}".format(type(value)))
+                "Can only assign strings, lists or None to name attributes."
+                " Got {0}".format(type(value)))
         setattr(self, attr+"_list", self.parse_pieces(val))
 
     @title.setter
@@ -298,22 +372,32 @@ class HumanName(object):
     def nickname(self, value):
         self._set_list('nickname', value)
 
-    ### Parse helpers
+    # Parse helpers
 
     def is_title(self, value):
         """Is in the :py:data:`~nameparser.config.titles.TITLES` set."""
         return lc(value) in self.C.titles
 
     def is_conjunction(self, piece):
-        """Is in the conjuctions set and not :py:func:`is_an_initial()`."""
-        return piece.lower() in self.C.conjunctions and not self.is_an_initial(piece)
+        """Is in the conjunctions set and not :py:func:`is_an_initial()`."""
+        if isinstance(piece, list):
+            for item in piece:
+                if self.is_conjunction(item):
+                    return True
+        else:
+            return piece.lower() in self.C.conjunctions and not self.is_an_initial(piece)
 
     def is_prefix(self, piece):
         """
         Lowercase and no periods version of piece is in the
         :py:data:`~nameparser.config.prefixes.PREFIXES` set.
         """
-        return lc(piece) in self.C.prefixes
+        if isinstance(piece, list):
+            for item in piece:
+                if self.is_prefix(item):
+                    return True
+        else:
+            return lc(piece) in self.C.prefixes
 
     def is_roman_numeral(self, value):
         """
@@ -331,9 +415,14 @@ class HumanName(object):
         `C.suffix_acronyms`.
         """
         # suffixes may have periods inside them like "M.D."
-        return ((lc(piece).replace('.','') in self.C.suffix_acronyms) \
-            or (lc(piece) in self.C.suffix_not_acronyms)) \
-            and not self.is_an_initial(piece)
+        if isinstance(piece, list):
+            for item in piece:
+                if self.is_suffix(item):
+                    return True
+        else:
+            return ((lc(piece).replace('.', '') in self.C.suffix_acronyms)
+                    or (lc(piece) in self.C.suffix_not_acronyms)) \
+                and not self.is_an_initial(piece)
 
     def are_suffixes(self, pieces):
         """Return True if all pieces are suffixes."""
@@ -358,8 +447,7 @@ class HumanName(object):
         """
         return bool(self.C.regexes.initial.match(value))
 
-
-    ### full_name parser
+    # full_name parser
 
     @property
     def full_name(self):
@@ -376,7 +464,7 @@ class HumanName(object):
 
     def collapse_whitespace(self, string):
         # collapse multiple spaces into single space
-        string =  self.C.regexes.spaces.sub(" ", string.strip())
+        string = self.C.regexes.spaces.sub(" ", string.strip())
         if string.endswith(","):
             string = string[:-1]
         return string
@@ -404,11 +492,14 @@ class HumanName(object):
         self.handle_capitalization()
 
     def fix_phd(self):
-        _re =  self.C.regexes.phd
-        match = _re.search(self._full_name)
-        if match:
-            self.suffix_list.append(match.group(1))
-            self._full_name = _re.sub('', self._full_name)
+        try:
+            _re = self.C.regexes.phd
+            match = _re.search(self._full_name)
+            if match:
+                self.suffix_list.append(match.group(1))
+                self._full_name = _re.sub('', self._full_name)
+        except AttributeError:
+            pass
 
     def parse_nicknames(self):
         """
@@ -422,10 +513,12 @@ class HumanName(object):
         Loops through 3 :py:data:`~nameparser.config.regexes.REGEXES`;
         `quoted_word`, `double_quotes` and `parenthesis`.
         """
-
-        re_quoted_word = self.C.regexes.quoted_word
-        re_double_quotes = self.C.regexes.double_quotes
-        re_parenthesis = self.C.regexes.parenthesis
+        
+        empty_re = re.compile("")
+        
+        re_quoted_word = self.C.regexes.quoted_word or empty_re
+        re_double_quotes = self.C.regexes.double_quotes or empty_re
+        re_parenthesis = self.C.regexes.parenthesis or empty_re
 
         for _re in (re_quoted_word, re_double_quotes, re_parenthesis):
             if _re.search(self._full_name):
@@ -474,7 +567,6 @@ class HumanName(object):
         self.nickname_list = []
         self.unparsable = True
 
-
         self.pre_process()
 
         self._full_name = self.collapse_whitespace(self._full_name)
@@ -516,7 +608,7 @@ class HumanName(object):
                             # numeral but this piece is not an initial
                             self.is_roman_numeral(nxt) and i == p_len - 2
                             and not self.is_an_initial(piece)
-                        ):
+                ):
                     self.last_list.append(piece)
                     self.suffix_list += pieces[i+1:]
                     break
@@ -540,7 +632,6 @@ class HumanName(object):
                 # title first middle last [suffix], suffix [suffix] [, suffix]
                 #               parts[0],          parts[1:...]
 
-
                 self.suffix_list += parts[1:]
                 pieces = self.parse_pieces(parts[0].split(' '))
                 log.debug("pieces: %s", u(pieces))
@@ -614,7 +705,6 @@ class HumanName(object):
             self.unparsable = False
         self.post_process()
 
-
     def parse_pieces(self, parts, additional_parts_count=0):
         """
         Split parts on spaces and remove commas, join on conjunctions and
@@ -644,11 +734,11 @@ class HumanName(object):
         # constants so they get parsed correctly later
         for part in output:
             # if this part has a period not at the beginning or end
-            if self.C.regexes.period_not_at_end.match(part):
+            if self.C.regexes.period_not_at_end and self.C.regexes.period_not_at_end.match(part):
                 # split on periods, any of the split pieces titles or suffixes?
                 # ("Lt.Gov.")
                 period_chunks = part.split(".")
-                titles   = list(filter(self.is_title,  period_chunks))
+                titles = list(filter(self.is_title,  period_chunks))
                 suffixes = list(filter(self.is_suffix, period_chunks))
 
                 # add the part to the constant so it will be found
@@ -695,7 +785,7 @@ class HumanName(object):
         # other, then join those newly joined conjunctions and any single
         # conjunctions to the piece before and after it
         conj_index = [i for i, piece in enumerate(pieces)
-                                if self.is_conjunction(piece)]
+                      if self.is_conjunction(piece)]
 
         contiguous_conj_i = []
         for i, val in enumerate(conj_index):
@@ -710,14 +800,14 @@ class HumanName(object):
         delete_i = []
         for i in contiguous_conj_i:
             if type(i) == tuple:
-                new_piece = " ".join(pieces[ i[0] : i[1]+1] )
-                delete_i += list(range( i[0]+1, i[1]+1 ))
+                new_piece = " ".join(pieces[i[0]: i[1]+1])
+                delete_i += list(range(i[0]+1, i[1]+1))
                 pieces[i[0]] = new_piece
             else:
-                new_piece = " ".join(pieces[ i : i+2 ])
+                new_piece = " ".join(pieces[i: i+2])
                 delete_i += [i+1]
                 pieces[i] = new_piece
-            #add newly joined conjunctions to constants to be found later
+            # add newly joined conjunctions to constants to be found later
             self.C.conjunctions.add(new_piece)
 
         for i in reversed(delete_i):
@@ -747,9 +837,9 @@ class HumanName(object):
                 pieces[i] = new_piece
                 pieces.pop(i+1)
                 # subtract 1 from the index of all the remaining conjunctions
-                for j,val in enumerate(conj_index):
+                for j, val in enumerate(conj_index):
                     if val > i:
-                        conj_index[j]=val-1
+                        conj_index[j] = val-1
 
             else:
                 new_piece = " ".join(pieces[i-1:i+2])
@@ -766,11 +856,10 @@ class HumanName(object):
 
                 # subtract the number of removed pieces from the index
                 # of all the remaining conjunctions
-                for j,val in enumerate(conj_index):
+                for j, val in enumerate(conj_index):
                     if val > i:
                         conj_index[j] = val - rm_count
 
-
         # join prefixes to following lastnames: ['de la Vega'], ['van Buren']
         prefixes = list(filter(self.is_prefix, pieces))
         if prefixes:
@@ -790,6 +879,9 @@ class HumanName(object):
                 # join everything after the prefix until the next prefix or suffix
 
                 try:
+                    if i == 0 and total_length >= 1:
+                        # If it's the first piece and there are more than 1 rootnames, assume it's a first name
+                        continue
                     next_prefix = next(iter(filter(self.is_prefix, pieces[i + 1:])))
                     j = pieces.index(next_prefix)
                     if j == i + 1:
@@ -813,12 +905,11 @@ class HumanName(object):
         log.debug("pieces: %s", pieces)
         return pieces
 
-
-    ### Capitalization Support
+    # Capitalization Support
 
     def cap_word(self, word, attribute):
-        if (self.is_prefix(word) and attribute in ('last','middle')) \
-                    or self.is_conjunction(word):
+        if (self.is_prefix(word) and attribute in ('last', 'middle')) \
+                or self.is_conjunction(word):
             return word.lower()
         exceptions = self.C.capitalization_exceptions
         if lc(word) in exceptions:
@@ -834,7 +925,8 @@ class HumanName(object):
     def cap_piece(self, piece, attribute):
         if not piece:
             return ""
-        replacement = lambda m: self.cap_word(m.group(0), attribute)
+
+        def replacement(m): return self.cap_word(m.group(0), attribute)
         return self.C.regexes.word.sub(replacement, piece)
 
     def capitalize(self, force=None):
@@ -872,10 +964,10 @@ class HumanName(object):
 
         if not force and not (name == name.upper() or name == name.lower()):
             return
-        self.title_list  = self.cap_piece(self.title , 'title').split(' ')
-        self.first_list  = self.cap_piece(self.first , 'first').split(' ')
+        self.title_list = self.cap_piece(self.title, 'title').split(' ')
+        self.first_list = self.cap_piece(self.first, 'first').split(' ')
         self.middle_list = self.cap_piece(self.middle, 'middle').split(' ')
-        self.last_list   = self.cap_piece(self.last  , 'last').split(' ')
+        self.last_list = self.cap_piece(self.last, 'last').split(' ')
         self.suffix_list = self.cap_piece(self.suffix, 'suffix').split(', ')
 
     def handle_capitalization(self):
